@@ -26,7 +26,6 @@ class Badminton():
         self.stocks, self.selects, self.results = [], [], []
         self.capt, self.imbyte = None, None
         self.max_times = max_times
-        self.begin_hour = time(int(begin_time.split(':')[0]), int(begin_time.split(':')[1]))
         self.token = token
 
         try:
@@ -41,6 +40,7 @@ class Badminton():
         if (self.netid == '') or (self.password == ''):
             print('填写 netid 和密码')
             sys.exit()
+
         try:
             self.stock_name = [int(i) for i in conf['stock_name'].split(',')]
             self.stock_time = [int(i) for i in conf['stock_time'].split(',')]
@@ -50,12 +50,18 @@ class Badminton():
             else:
                 self.stock_date = datetime.strptime(
                     conf['stock_date'], "%Y-%m-%d").date()
+            # 预定日期前一天 00:00 可以预定，当天 22:00 后无法预定
+            self.begin_time = datetime.strptime(begin_time, "%H:%M").time()
+            self.begin_datetime = datetime.combine(self.stock_date,
+                                                    self.begin_time) - timedelta(days=1)
+            self.end_datetime = datetime.combine(self.stock_date, time(22, 0))
         except ValueError:
             print('检查配置文件填写是否正确')
             sys.exit()
 
         print(f'预定日期: {self.stock_date}')
         print(f"预定场次: {conf['stock_name']}\n预定时间: {conf['stock_time']}")
+        print(f'每个时间段最大预定场地数: {self.stock_number}')
 
 
     def get_stocks(self):
@@ -70,12 +76,11 @@ class Badminton():
             try:
                 json_data = json.loads(r.text)
             except JSONDecodeError:
-                if r.status_code == 502:
-                    print('目测服务器崩溃了，等待一分钟后重试')
+                if r.status_code != 200:
+                    print(f'状态码: {r.status_code}，服务器可能崩溃了，等待一分钟后重试')
                     sleep(60)
                     continue
                 print(f'获取场地信息失败，第 {try_times} 次重试')
-                print(r.status_code)
                 sleep(3)
                 continue
             stocks = json_data['object']
@@ -137,7 +142,7 @@ class Badminton():
         recg_times = 0
         while recg_times < self.max_times:
             r = requests.post(f'http://api.95man.com:8888/api/Http/Recog?Taken={self.token}&imgtype=1&len=4',
-                            files=files, headers=headers)
+                              files=files, headers=headers)
             arrstr = r.text.split('|')
             # 返回格式: 识别ID|识别结果|用户余额
             if int(arrstr[0]) > 0:
@@ -169,7 +174,7 @@ class Badminton():
                       }
         login_times = 0
 
-        while login_times < 6:
+        while login_times < self.max_times:
             login_times += 1
             r = self.session.get(self_url, headers=headers)
             if '欢迎' in r.text:
@@ -202,76 +207,39 @@ class Badminton():
         print('登录重试次数太多，终止')
         sys.exit()
 
-    def waite(self):
+
+    def wait(self):
         """系统正常开启时间为 00:00-22:00，选择合适等待策略
         """
-        # 判断预订系统是否开放
-        today = date.today()
-        begin_time = datetime.combine(today, self.begin_hour)
-        end_time = datetime.combine(today, time(22, 0))
         now_time = datetime.now()
-        if now_time < begin_time:
-            # 早了
-            stock = 0
-        elif now_time > end_time:
-            # 晚了
-            stock = -1
-        else:
-            # 刚好
-            stock = 1
 
-        # 判断选定的日期是否可以预订
-        if self.stock_date < today:
-            print(f'预订日期已经过去，你可以穿越回 {self.stock_date}，再见')
-            sys.exit()
-        if self.stock_date == today:
-            if stock == 1:
-                print(f'当前时间 {datetime.now()}，开始预订')
-                return True
-            if stock == -1:
-                print('预订日期已经过去，你可以穿越回 22:00 前，再见')
-                sys.exit()
-            if stock == 0:
-                begin_time = datetime.combine(self.stock_date, self.begin_hour)
-
-        elif self.stock_date == (today + timedelta(days=1)):
-            if stock == 1:
-                print(f'当前时间 {datetime.now()}，开始预订')
-                return True
-            if stock == -1:
-                begin_time = datetime.combine(self.stock_date, self.begin_hour)
-                print('预订系统已关闭')
-            elif stock == 0:
-                begin_time = datetime.combine(
-                    self.stock_date - timedelta(days=1), self.begin_hour)
-
-        elif self.stock_date > (today + timedelta(days=1)):
-            # 等到前一天 00:00 才能预订
-            begin_time = datetime.combine(
-                self.stock_date - timedelta(days=1), self.begin_hour)
-            print('超过目前可预订日期')
-        else:
-            print('超出判断条件，你也是个人才')
+        if now_time > self.end_datetime:
+            print(f'预订日期已经过去，你可以穿越回 {self.end_datetime} 之前，再见')
             sys.exit()
 
-        print(f'等到 {begin_time} 预订，开始 sleep')
-        if (begin_time - datetime.now()).days > 0:
-            print('等待时间超过一天，个人建议等到明天再来预定')
-            sleep((begin_time - datetime.now()).days * 86400)
+        if now_time > self.begin_datetime:
+            if now_time.hour < 22:
+                print(f'当前时间 {datetime.now()}，开始预订')
+                return
+            self.begin_datetime += timedelta(days=1)
+            print('预订系统关闭，等到明天开始预定')
 
-        while ((begin_time - datetime.now()).seconds - 1) > 200:
-            print(f'{begin_time - datetime.now()} 后开始预订')
-            sleep((begin_time - datetime.now()).seconds - 180)
-
-        print(f'{begin_time - datetime.now()} 后开始预订')
+        print(f'未到可预订时间，等到 {self.begin_datetime} 开始预定')
+        if (self.begin_datetime - datetime.now()).days > 0:
+            print('!!!警告!!!')
+            print('等待时间超过一天，建议等到明天再来预定!!!')
+        print(f'{self.begin_datetime - datetime.now()} 后开始预订')
+        sleep((self.begin_datetime - datetime.now()).seconds - 120)
+        print('检查登录状态')
         if self.login():
-            sleep((begin_time - datetime.now()).seconds + 3)
-            return True
-        print(f'{datetime.now()} 登录无效，尝试重新登录')
-        return False
+            print(f'{self.begin_datetime - datetime.now()} 后开始预订')
+            sleep((self.begin_datetime - datetime.now()).seconds - 3)
+            return
 
 
     def book(self):
+        """预订场地
+        """
         stock_index = 0
         book_times = 0
         while len(self.results) < 2 and book_times < 10:
@@ -324,11 +292,14 @@ class Badminton():
             print('预定失败，重试次数过多，退出')
             sys.exit()
         print(f'预订成功 {len(self.results)} 个场地，1 分钟后自动支付订单')
+        sleep(60)
 
 
     def pay(self):
+        """支付订单
+        """
         pay_times = 0
-        while pay_times < 10 and len(self.results) != 0:
+        while pay_times < self.max_times and len(self.results) != 0:
             pay_times += 1
             result = self.results[0]
             print('支付订单  ' + str(result[0]))
@@ -361,34 +332,27 @@ class Badminton():
 
 
     def run(self):
-        try_times = 0
-        while try_times < 10:
-            self.login()
-            if not self.waite():
-                # 重新登录
-                sleep(3)
-                try_times += 1
-                continue
+        self.login()
+        self.wait()
+        self.get_stocks()
+        self.select()
+        self.book()
+        self.pay()
+        sys.exit()
 
-            self.get_stocks()
-            self.select()
-            self.book()
-            sleep(60)
-            self.pay()
-            sys.exit()
 
 def main():
     parser = argparse.ArgumentParser(description='预定中山大学珠海校区羽毛球场地')
-    parser.add_argument('-c', '--config', type=str, help='配置文件路径', required=True)
-    parser.add_argument('-b', '--begin', type=str, help='预定开始时间', default='00:01')
-    parser.add_argument('-m', '--maxtimes', type=int, help='最大预定次数', default=10)
+    parser.add_argument('config', type=str, help='配置文件路径')
+    parser.add_argument('-b', '--begin', metavar='BEGIN TIME', type=str,
+                        help='预定开始时间，如 00:05，默认 00:01', default='00:01')
+    parser.add_argument('-m', '--maxtimes', type=int, help='最大重试次数', default=10)
     parser.add_argument('-t', '--token', type=str,
                         help='验证码识别平台token', default='Hvfn8AbwxNTySxrnmTknA06onCdb')
+    parser.add_argument('-v', '--version', action='version', version='%(prog)s 0.3.0')
     par = parser.parse_args()
     badminton = Badminton(par.config, par.begin, par.maxtimes, par.token)
     badminton.run()
 
 if __name__ == '__main__':
     main()
-
-# %%
